# Terms of Use

Welcome to {{app_name}}!

These Terms of Use ("Terms") govern your use of {{app_name}} and the services offered through the platform.

## Acceptance of Terms

By accessing and using {{app_name}}, you accept and agree to be bound by the terms and provision of this agreement.

## Use License

Permission is granted to temporarily download one copy of {{app_name}} for personal, non-commercial transitory viewing only.

## Disclaimer

The materials on {{app_name}} are provided on an 'as is' basis. {{app_name}} makes no warranties, expressed or implied, and hereby disclaims and negates all other warranties including without limitation, implied warranties or conditions of merchantability, fitness for a particular purpose, or non-infringement of intellectual property or other violation of rights.

## Limitations

In no event shall {{app_name}} or its suppliers be liable for any damages (including, without limitation, damages for loss of data or profit, or due to business interruption) arising out of the use or inability to use {{app_name}}, even if {{app_name}} or an authorized representative has been notified orally or in writing of the possibility of such damage.

## Contact Information

If you have any questions about these Terms of Use, please contact us through {{app_name}}.

---

Last updated: 17 September 2025